@@ -28,11 +28,25 @@ class Client:
 
     @property
     def deployables(self):
+        if not hasattr(self, "_deployables"):
+            response = self.list_deployables()
+            self._deployables = sorted(
+                response["deployables"], key=lambda x: x["insert_date_"]
+            )
         return self._deployables
 
     def recent(self) -> dashboard.Dashboard:
-        kwargs = self.deployables[-1]
-        return dashboard.Dashboard(endpoints=self._endpoints, **kwargs)
+        configuration = self.deployables[-1]
+        dataset_id = configuration.get("dataset_id")
+        deployable_id = configuration.get("deployable_id")
+        project_id = configuration.get("project_id")
+        return dashboard.Dashboard(
+            endpoints=self._endpoints,
+            dataset_id=dataset_id,
+            deployable_id=deployable_id,
+            configuration=configuration,
+            project_id=project_id,
+        )
 
     def list_deployables(self, page_size: int = 1000):
         return self._endpoints._list_deployables(page_size=page_size)
