@@ -11,6 +11,7 @@ def aggregation_chart(
     sentiment_field: str = "",
     y_axis_sort_field: str = "",
     sort_direction: str = "desc",
+    filters: Optional[List[Dict[str, Any]]] = None,
 ):
     """
     Example for groupby
@@ -39,6 +40,9 @@ def aggregation_chart(
     for query in metric:
         query["aggType"] = "metric"
 
+    if filters is None:
+        filters = []
+
     return [
         {
             "type": "appBlock",
@@ -49,7 +53,7 @@ def aggregation_chart(
                         "uid": "",
                         "title": title,
                         "chartType": chart_type,
-                        "filters": [],
+                        "filters": filters,
                         "xAxis": {
                             "fields": groupby,
                             "numResults": page_size,
